@@ -37,7 +37,7 @@ class SampleTest(unittest.TestCase):
 
         jdata = os.path.join(DATAFILES_PATH, 'bernoulli.data.json')
         bern_fit = bern_model.sample(
-            data=jdata, chains=4, cores=2, seed=12345, sampling_iters=100
+            data=jdata, chains=4, cores=2, seed=12345, iter_sampling=100
         )
         self.assertIn('CmdStanMCMC: model=bernoulli', bern_fit.__repr__())
         self.assertIn('method=sample', bern_fit.__repr__())
@@ -46,9 +46,9 @@ class SampleTest(unittest.TestCase):
 
         for i in range(bern_fit.runset.chains):
             csv_file = bern_fit.runset.csv_files[i]
-            txt_file = ''.join([os.path.splitext(csv_file)[0], '.txt'])
+            stdout_file = bern_fit.runset.stdout_files[i]
             self.assertTrue(os.path.exists(csv_file))
-            self.assertTrue(os.path.exists(txt_file))
+            self.assertTrue(os.path.exists(stdout_file))
 
         self.assertEqual(bern_fit.runset.chains, 4)
         self.assertEqual(bern_fit.draws, 100)
@@ -75,30 +75,32 @@ class SampleTest(unittest.TestCase):
             chains=4,
             cores=2,
             seed=12345,
-            sampling_iters=100,
+            iter_sampling=100,
             output_dir=DATAFILES_PATH,
         )
         for i in range(bern_fit.runset.chains):
             csv_file = bern_fit.runset.csv_files[i]
-            txt_file = ''.join([os.path.splitext(csv_file)[0], '.txt'])
+            stdout_file = bern_fit.runset.stdout_files[i]
             self.assertTrue(os.path.exists(csv_file))
-            self.assertTrue(os.path.exists(txt_file))
+            self.assertTrue(os.path.exists(stdout_file))
         bern_sample = bern_fit.sample
         self.assertEqual(bern_sample.shape, (100, 4, len(column_names)))
         for i in range(bern_fit.runset.chains):  # cleanup datafile_path dir
             os.remove(bern_fit.runset.csv_files[i])
-            os.remove(bern_fit.runset.console_files[i])
-
+            if os.path.exists(bern_fit.runset.stdout_files[i]):
+                os.remove(bern_fit.runset.stdout_files[i])
+            if os.path.exists(bern_fit.runset.stderr_files[i]):
+                os.remove(bern_fit.runset.stderr_files[i])
         rdata = os.path.join(DATAFILES_PATH, 'bernoulli.data.R')
         bern_fit = bern_model.sample(
-            data=rdata, chains=4, cores=2, seed=12345, sampling_iters=100
+            data=rdata, chains=4, cores=2, seed=12345, iter_sampling=100
         )
         bern_sample = bern_fit.sample
         self.assertEqual(bern_sample.shape, (100, 4, len(column_names)))
 
         data_dict = {'N': 10, 'y': [0, 1, 0, 0, 0, 0, 0, 0, 0, 1]}
         bern_fit = bern_model.sample(
-            data=data_dict, chains=4, cores=2, seed=12345, sampling_iters=100
+            data=data_dict, chains=4, cores=2, seed=12345, iter_sampling=100
         )
         bern_sample = bern_fit.sample
         self.assertEqual(bern_sample.shape, (100, 4, len(column_names)))
@@ -109,26 +111,26 @@ class SampleTest(unittest.TestCase):
         jdata = os.path.join(DATAFILES_PATH, 'bernoulli.data.json')
 
         bern_fit = bern_model.sample(
-            data=jdata, chains=4, cores=2, seed=12345, sampling_iters=100,
+            data=jdata, chains=4, cores=2, seed=12345, iter_sampling=100,
             inits=1.1
         )
         self.assertIn('init=1.1', bern_fit.runset.__repr__())
 
         bern_fit = bern_model.sample(
-            data=jdata, chains=4, cores=2, seed=12345, sampling_iters=100,
+            data=jdata, chains=4, cores=2, seed=12345, iter_sampling=100,
             inits=1
         )
         self.assertIn('init=1', bern_fit.runset.__repr__())
 
         with self.assertRaises(ValueError):
             bern_model.sample(
-                data=jdata, chains=4, cores=2, seed=12345, sampling_iters=100,
+                data=jdata, chains=4, cores=2, seed=12345, iter_sampling=100,
                 inits=(1, 2)
             )
 
         with self.assertRaises(ValueError):
             bern_model.sample(
-                data=jdata, chains=4, cores=2, seed=12345, sampling_iters=100,
+                data=jdata, chains=4, cores=2, seed=12345, iter_sampling=100,
                 inits=-1
             )
 
@@ -136,9 +138,15 @@ class SampleTest(unittest.TestCase):
         stan = os.path.join(DATAFILES_PATH, 'bernoulli.stan')
         bern_model = CmdStanModel(stan_file=stan)
 
-        with self.assertRaisesRegex(Exception, 'Error during sampling'):
+        with self.assertRaisesRegex(RuntimeError, 'variable does not exist'):
             bern_model.sample(
-                chains=4, cores=2, seed=12345, sampling_iters=100
+                chains=4, cores=2, seed=12345, iter_sampling=100
+            )
+
+        with self.assertRaisesRegex(RuntimeError, 'variable does not exist'):
+            bern_model.sample(
+                data={'foo': 1},
+                chains=4, cores=2, seed=12345, iter_sampling=100
             )
 
     def test_multi_proc(self):
@@ -176,15 +184,15 @@ class SampleTest(unittest.TestCase):
         datagen_model = CmdStanModel(stan_file=stan)
         no_data = {}
         datagen_fit = datagen_model.sample(
-            data=no_data, seed=12345, sampling_iters=100, fixed_param=True
+            data=no_data, seed=12345, iter_sampling=100, fixed_param=True
         )
         self.assertEqual(datagen_fit.runset._args.method, Method.SAMPLE)
 
         for i in range(datagen_fit.runset.chains):
             csv_file = datagen_fit.runset.csv_files[i]
-            txt_file = ''.join([os.path.splitext(csv_file)[0], '.txt'])
+            stdout_file = datagen_fit.runset.stdout_files[i]
             self.assertTrue(os.path.exists(csv_file))
-            self.assertTrue(os.path.exists(txt_file))
+            self.assertTrue(os.path.exists(stdout_file))
 
         self.assertEqual(datagen_fit.runset.chains, 1)
 
@@ -296,7 +304,7 @@ class CmdStanMCMCTest(unittest.TestCase):
         exe = os.path.join(DATAFILES_PATH, 'bernoulli' + EXTENSION)
         jdata = os.path.join(DATAFILES_PATH, 'bernoulli.data.json')
         sampler_args = SamplerArgs(
-            sampling_iters=100, max_treedepth=11, adapt_delta=0.95
+            iter_sampling=100, max_treedepth=11, adapt_delta=0.95
         )
         cmdstan_args = CmdStanArgs(
             model_name='bernoulli',
@@ -406,7 +414,7 @@ class CmdStanMCMCTest(unittest.TestCase):
         jmetric = os.path.join(DATAFILES_PATH, 'bernoulli.metric.json')
         # just test that it runs without error
         bern_model.sample(
-            data=jdata, chains=4, cores=2, seed=12345, sampling_iters=200,
+            data=jdata, chains=4, cores=2, seed=12345, iter_sampling=200,
             metric=jmetric,
         )
 
@@ -415,13 +423,13 @@ class CmdStanMCMCTest(unittest.TestCase):
         jdata = os.path.join(DATAFILES_PATH, 'bernoulli.data.json')
         bern_model = CmdStanModel(stan_file=stan)
         bern_fit = bern_model.sample(
-            data=jdata, chains=4, cores=2, seed=12345, sampling_iters=200
+            data=jdata, chains=4, cores=2, seed=12345, iter_sampling=200
         )
         for i in range(bern_fit.runset.chains):
             csv_file = bern_fit.runset.csv_files[i]
-            txt_file = ''.join([os.path.splitext(csv_file)[0], '.txt'])
+            stdout_file = bern_fit.runset.stdout_files[i]
             self.assertTrue(os.path.exists(csv_file))
-            self.assertTrue(os.path.exists(txt_file))
+            self.assertTrue(os.path.exists(stdout_file))
 
         # save files to good dir
         bern_fit.save_csvfiles(dir=DATAFILES_PATH)
@@ -439,12 +447,15 @@ class CmdStanMCMCTest(unittest.TestCase):
             self.assertTrue(os.path.exists(csv_file))
         for i in range(bern_fit.runset.chains):  # cleanup datafile_path dir
             os.remove(bern_fit.runset.csv_files[i])
-            os.remove(bern_fit.runset.console_files[i])
+            if os.path.exists(bern_fit.runset.stdout_files[i]):
+                os.remove(bern_fit.runset.stdout_files[i])
+            if os.path.exists(bern_fit.runset.stderr_files[i]):
+                os.remove(bern_fit.runset.stderr_files[i])
         shutil.rmtree(tmp2_dir, ignore_errors=True)
 
         # regenerate to tmpdir, save to good dir
         bern_fit = bern_model.sample(
-            data=jdata, chains=4, cores=2, seed=12345, sampling_iters=200
+            data=jdata, chains=4, cores=2, seed=12345, iter_sampling=200
         )
         bern_fit.save_csvfiles()  # default dir
         for i in range(bern_fit.runset.chains):
@@ -452,7 +463,10 @@ class CmdStanMCMCTest(unittest.TestCase):
             self.assertTrue(os.path.exists(csv_file))
         for i in range(bern_fit.runset.chains):  # cleanup default dir
             os.remove(bern_fit.runset.csv_files[i])
-            os.remove(bern_fit.runset.console_files[i])
+            if os.path.exists(bern_fit.runset.stdout_files[i]):
+                os.remove(bern_fit.runset.stdout_files[i])
+            if os.path.exists(bern_fit.runset.stderr_files[i]):
+                os.remove(bern_fit.runset.stderr_files[i])
 
     def test_diagnose_divergences(self):
         exe = os.path.join(
@@ -489,7 +503,7 @@ class CmdStanMCMCTest(unittest.TestCase):
         exe = os.path.join(DATAFILES_PATH, 'bernoulli' + EXTENSION)
         jdata = os.path.join(DATAFILES_PATH, 'bernoulli.data.json')
         sampler_args = SamplerArgs(
-            sampling_iters=100, max_treedepth=11, adapt_delta=0.95
+            iter_sampling=100, max_treedepth=11, adapt_delta=0.95
         )
 
         # some chains had errors
@@ -508,7 +522,7 @@ class CmdStanMCMCTest(unittest.TestCase):
         self.assertTrue(runset._check_retcodes())
 
         # errors reported
-        runset._console_files = [
+        runset._stderr_files = [
             os.path.join(DATAFILES_PATH, 'runset-bad',
                              'bad-transcript-bern-1.txt'),
             os.path.join(DATAFILES_PATH, 'runset-bad',
@@ -518,8 +532,7 @@ class CmdStanMCMCTest(unittest.TestCase):
             os.path.join(DATAFILES_PATH, 'runset-bad',
                              'bad-transcript-bern-4.txt'),
             ]
-        with self.assertRaisesRegex(Exception, 'Exception'):
-            runset._check_console_msgs()
+        self.assertEqual(len(runset._get_err_msgs()), 4)
 
         # csv file headers inconsistent
         runset._csv_files = [
